@@ -53,7 +53,7 @@ class TSPipeline(object):
     Core TimeStream pipeline runner.
     """
 
-    def __init__(self, *args, reporter=None, record_step_times=False, step_id=None):
+    def __init__(self, *args, reporter=None, record_step_times=False, step_id=None, multi_file_pipeline=False):
         r"""
         :param \*args: Pipeline steps to execute
         :type \*args: :class:`.PipelineStep`
@@ -63,6 +63,8 @@ class TSPipeline(object):
         :type record_step_times: bool
         :param step_id: (options) when record_step_times is True, what to record the step name as
         :type step_id: str
+        :param multi_file_pipeline: Set True to disable per-file reporting and verification, for functions like gvmosaic
+        :type multi_file_pipeline: bool
         """
         if step_id:
             self.step_id = step_id
@@ -75,6 +77,7 @@ class TSPipeline(object):
         if reporter is None:
             reporter = ResultRecorder()
         self.report = reporter
+        self.multi_file_pipeline = multi_file_pipeline
 
     def add_step(self, step):
         """Appends steps to this pipeline.
@@ -99,7 +102,8 @@ class TSPipeline(object):
             t = time.time()
             try:
                 file = step.process_file(file)
-                assert file is not None
+                if self.multi_file_pipeline is False:
+                    assert file is not None
             except AbortPipelineForThisImage as exc:
                 file.report.update({"PipelineAbortedMessage": str(exc)})
                 print(f"\nAborting at {step.__class__.__name__}: {str(exc)}", file=stderr)
@@ -127,7 +131,8 @@ class TSPipeline(object):
                     file.report[fname] += time.time() - t
                 else:
                     file.report[fname] = time.time() - t
-        self.report.record(file.instant, **file.report)
+        if (self.multi_file_pipeline is False) or (file is not None):
+            self.report.record(file.instant, **file.report)
         return file
 
     def process(self, input_stream, ncpus=1, progress=True):
