@@ -19,6 +19,12 @@ from pyts2.time import *
 from pyts2.utils import *
 from pyts2.filelock import FileLock
 
+try:
+    from tqdm import tqdm
+    _HAVE_TQDM = True
+except ImportError:
+    _HAVE_TQDM = False
+
 
 def get_instant_or_fn(path):
     try:
@@ -465,7 +471,8 @@ class TimeStream(object):
                 with FileLock(self._index_file):
                     try:
                         if progress:
-                            itr = tqdm(itr)
+                            if _HAVE_TQDM:
+                                itr = tqdm(itr)
                             with open(self._index_file, "w") as fh:
                                 for f in itr:
                                     self._instants[f.instant] = f.fetcher
